@@ -13,7 +13,7 @@ from .BrowserStack_Library import BrowserStack_Library
 from .driverfactory import DriverFactory
 # from utils.Test_Rail import Test_Rail
 # from utils import Tesults
-from stop_test_exception_util import Stop_Test_Exception
+from .stop_test_exception_util import Stop_Test_Exception
 from . import remote_credentials
 from . import base_url_conf
 from . import screenshot_conf
